summaryrefslogtreecommitdiffstats
path: root/filters/kword/oowriter/oowriterimport.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /filters/kword/oowriter/oowriterimport.cc
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'filters/kword/oowriter/oowriterimport.cc')
-rw-r--r--filters/kword/oowriter/oowriterimport.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/filters/kword/oowriter/oowriterimport.cc b/filters/kword/oowriter/oowriterimport.cc
index 87e41f492..3f267bebc 100644
--- a/filters/kword/oowriter/oowriterimport.cc
+++ b/filters/kword/oowriter/oowriterimport.cc
@@ -596,7 +596,7 @@ bool OoWriterImport::createStyleMap( const TQDomDocument & styles, TQDomDocument
if ( d > 1.0 )
{
TQString message( i18n("This document was created with OpenOffice.org version '%1'. This filter was written for version 1.0. Reading this file could cause strange behavior, crashes or incorrect display of the data. Do you want to continue converting the document?") );
- message = message.tqarg( docElement.attributeNS( ooNS::office, "version", TQString() ) );
+ message = message.arg( docElement.attributeNS( ooNS::office, "version", TQString() ) );
if ( KMessageBox::warningYesNo( 0, message, i18n( "Unsupported document version" ) ) == KMessageBox::No )
return false;
}
@@ -992,11 +992,11 @@ void OoWriterImport::parseList( TQDomDocument& doc, const TQDomElement& list, TQ
static int numberOfParagraphs( const TQDomElement& frameset )
{
- const TQDomNodeList tqchildren = frameset.childNodes();
+ const TQDomNodeList children = frameset.childNodes();
const TQString paragStr = "PARAGRAPH";
int paragCount = 0;
- for ( unsigned int i = 0 ; i < tqchildren.length() ; ++i ) {
- if ( tqchildren.item( i ).toElement().tagName() == paragStr )
+ for ( unsigned int i = 0 ; i < children.length() ; ++i ) {
+ if ( children.item( i ).toElement().tagName() == paragStr )
++paragCount;
}
return paragCount;
@@ -1458,7 +1458,7 @@ void OoWriterImport::writeLayout( TQDomDocument& doc, TQDomElement& layoutElemen
{
Q_ASSERT( layoutElement.ownerDocument() == doc );
// Always write out the tqalignment, it's required
TQDomElement flowElement = doc.createElement("FLOW");
/* This was only an intermediate OASIS decision. The final decision is:
@@ -1563,7 +1563,7 @@ void OoWriterImport::writeLayout( TQDomDocument& doc, TQDomElement& layoutElemen
style:background-image
line numbering
punctuation wrap, 3.10.36
- vertical tqalignment - a bit like offsetfrombaseline (but not for subscript/superscript, in general)
+ vertical alignment - a bit like offsetfrombaseline (but not for subscript/superscript, in general)
Michael said those are in fact parag properties:
style:text-autospace, 3.10.32 - not implemented in kotext
style:line-break, 3.10.37 - apparently that's for some Asian languages
@@ -2303,7 +2303,7 @@ void OoWriterImport::parseInsideOfTable( TQDomDocument &doc, const TQDomElement&
if ( localName == "table-cell" ) // OOo SPEC 4.8.1 p267
{
const TQString frameName(i18n("Frameset name","Table %3, row %1, column %2")
- .tqarg(row).tqarg(column).tqarg(tableName)); // The table name could have a % sequence, so use the table name as last!
+ .arg(row).arg(column).arg(tableName)); // The table name could have a % sequence, so use the table name as last!
kdDebug(30518) << "Trying to create " << frameName << endl;
// We need to create a frameset for the cell
@@ -1458,7 +1458,7 @@ void OoWriterImport::writeLayout( TQDomDocument& doc, TQDomElement& layoutElemen
{
Q_ASSERT( layoutElement.ownerDocument() == doc );
- // Always write out the tqalignment, it's required
+ // Always write out the alignment, it's required
TQDomElement flowElement = doc.createElement("FLOW");
/* This was only an intermediate OASIS decision. The final decision is: